.. lyricsfandom documentation master file, created by
   sphinx-quickstart on Fri May 22 00:03:11 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to scrapereads's documentation!
========================================

.. toctree::
    :maxdepth: 1
    :caption: Getting Started

    source/getting-started


.. toctree::
    :maxdepth: 1
    :caption: Examples

    source/example


.. toctree::
    :maxdepth: 1
    :caption: Package

    source/package

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
